@@ -21,21 +21,19 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import os, sys
+from TheMingServer import lib
 
 class HTMLMaker:
 	NAME = "HTMLMaker"
 	PLATE = "site.html"
 
-	def __init__(self, source, lib, debug):
+	def __init__(self, source):
 		self.source = source
-		self.lib = lib
-		self.debug = debug
-		return
 
 	def make(self, parsed_data, plate=None):
-		if (plate == None): plate = self.source+os.sep+self.PLATE
-		lines = self.lib.get_lines(plate)
-		if (lines == []):
-			sys.exit(self.NAME+": unable to read "+plate)
-		page = self.lib.insert_tags(lines, parsed_data)
+		if plate == None: plate = self.source + os.sep + self.PLATE
+		lines = lib.get_lines(plate)
+		if lines == []:
+			sys.exit(self.NAME + ": unable to read " + plate)
+		page = lib.insert_tags(lines, parsed_data)
 		return page
