@@ -25,11 +25,8 @@ from HTMLParser import HTMLParser
 class TTMLParser(HTMLParser):
 	NAME = "TTMLParser"
 
-	def __init__(self, lib, debug):
-		HTMLParser.__init__(self, lib, debug)
-		self.lib = lib
-		self.debug = debug
-		return
+	def __init__(self):
+		HTMLParser.__init__(self)
 
 	def __parse_3tml(self, lines):
 		new_lines = []
