@@ -21,21 +21,20 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import os
+from TheMingServer import debug
 
 class StaticWriter:
 	NAME = "StaticWriter"
 
-	def __init__(self, debug):
-		self.debug = debug
-		return
+	def __init__(self):
+		pass
 
 	def write(self, fname, page):
-		if (self.debug): print "Static: "+fname
+		if debug: print "Static: " + fname
 		dir = os.path.dirname(fname)
 		if not os.path.isdir(dir):
 			os.makedirs(dir)
 		page = "".join(page)
-		f = open(fname,'w')
+		f = open(fname, 'w')
 		f.write(page)
 		f.close()
-		return 
